bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 37. Aventiure
___________________________________________________
| ### <Ez> heten di ellende wider morgen gvt getan ### wine der Gotelinde chom ce hove gegan ### do sach er beidenthalben div grozlicher ser ### daz weinte innechlichen der vil gvte Rvdeger ### So we mir sprach der recke daz ich ie den lip gewan ### daz disen grozen iamer chan niemen vnderstan ### swi gerne <ichz> vriden wolde der chvenech entvt es niht ### wande er der sinen leide ie mer vnd mer gesiht
###### 2134 | ### Do sande an Dieterichen der gvte Rvedeger ### ob siz noch chvnden wenden an den chvenegen her ### do enbot im der von Berne wer moht iz vnderstan ### ezen wil der kvenech Ecel niemen scheiden lan
| ### Do sah ein Hivnen recke Rvedgeren stan ### mit weinenden ovgen [400b] vnde hetes vil getan ### der sprach cer kveneginne nv seht ir wi er stat ### der doch gewalt den meisten hi bi Eceln hat
###### 2136 | ### vnt dem allez dienet livt vnde lant ### wi so vil der bverge an <Rvedeger> gewant ### der er von dem chvenege vil manege haben mach ### er geslvch in disen stvermen nie lobelichen slach
###### 2137 | ### Mich dvnchet ern rv^che wi ez hi vmbe gat ### sit et der vollen nach sinem willen hat ### man giht im er si chvener danne iemen mvege sin ### daz ist in disen sorgen worden bosliche schin
| ### Mit trvrigem mvte der vil getriwe man ### den er daz reden horte der helt der blicht in an ### er dahte dv solt ez erarnen dv gihest ich si verzagt ### dv hast disiv mære ce hove ce lvte gesagt
###### 2139 | ### Di fvst begonder twingen do lief er in an ### vnde slvch so chrepftliche den hivnisschen man ### daz er im vor den fvzen lach vil shier tot ### <do> was aber gemeret des kvenech Eceln not
###### 2140 | ### Hin du zage mære sprach do Rvedger ### hich han doch genvge leit vnde ser ### daz ich hi niht envihte zwiv wizest dv mir daz ### ia wære ich den gesten von grozen schvlden gehaz
###### 2141 | ### <vnde> allez daz ich moehte het ich in getan ### niwan daz ich di recken her gefveret han ### ia was ich ir geleite in mines herren lant ### des en sol mit in niht striten min vil ellendes hant
###### 2142 | ### Do sprach ce dem margraven Ecel der kvenech her ### wi habt ir vns geholfen vil edel Rvedeger ### wand wir so vil der viegen hi ce lande han ### wir bedorften ir niht mere ir habt vil vebele getan
###### 2143 | ### Do sprach der ritter edele da besweret er mir den mvt ### vnde hat mir geitewizet ere vnde gvt ### des ich von dinen handen [401a] han so vil genomen ### daz ist dem lvgenære ein teil vnstæteliche chomen
| ### Do chom div chveneginne vnde het iz ovch gesehen ### daz von des heldes zorne dem Hivnen was geschehen ### si chlagetez vngefvge ir ovgen wrden naz ### si sprach ce Rvedegere wi habe wir verdienet daz
###### 2145 | ### daz ir mir vnt dem chvenege meret vnser leit ### nv habt ir vns edel Rvedger allez her geseit ### ir woldet dvrh vns wagen di ere vnde ovch daz leben ### ich hort iv vil der recken den pris vil groezlichen geben
###### 2146 | ### Ich man ivch der genaden vnd ir mir habt gesworn ### do ir mir ce Eceln rietet ritter vzerchorn ### daz ir mir woldet dienen an vnser eines tot ### des wart mir armem wibe nie so grozliche not
###### 2147 | ### <Daz> ist ane lovgen ich swor iv edel wip ### daz ich dvrch ivch wagete ere vnde ovch den lip ### daz ich di sele vliese desen han ich niht gesworn ### zv dirre hohgezite bat ich di fversten wol geborn
###### 2148 | ### Si sprach gedenche Rvedger der grozen triwe din ### der stæte vnd ovch der eide daz dv den schaden min ### immer woldest rêchen vnd elliv miniv leit ### do sprach der margrave ich han iv selten verseit
###### 2149 | ### Ecel der vil riche vlegen ovch began ### do bvten si sich ce fvzen beide fver den man ### den edelen margraven vnmvtes man do sach ### der vil getriwe recke harte iamerlichen sprach
| ### Owe mir gotes armem daz ich ie dice gelebet han ### aller miner eren der mvz ich abe stan ### triwen vnde zvehte der got an mir gebot ### owe got von himele daz miches niht wendet der tot
###### 2151 | ### Swelhez ich nv laze vnt daz ander began ### so han ich bosliche vnde vil vbele getan ### laze aber ich si beide mich schiltet elliv diet ### nv gervche mich bewisen der mir [401b] ce lebene geriet
###### 2152 | ### Do baten si in genote der chvenech vnd ovch sin wip ### si mvsen sider rechen verliesen den lip ### vor Rvedgeres hende da ovch der helt erstarp ### ir mveget daz hi wol hoeren daz er vil iamerlichen warp
###### 2153 | ### <Er> wiste schaden gewinnen vnd vngefvgiv leit ### er het dem chvenege vil gerne verseit ### vnd ovch der chveneginne vil sere vorhte er daz ### ob er ir einen slvege daz im div werlt werde gehaz
###### 2154 | ### Do sprach zv dem chvenege der vil chvene man ### her kvenech nv nemt hin widere al daz ich von iv han ### daz lant mit den bvergen der sol mir niht bestan ### ich wil vf minen fvzen in daz ellende gan
###### 2155 | ### Do sprach der kvenech Ecel wer hvelfe danne mir ### daz lant zv den livten daz gib ich allez dir ### daz dv mich rechest Rvedger an den vienden min ### dv solt ein kvenech gewaltech beneben Eceln sin
| ### Do sprach aber Rvedger wi sol iz ane van ### heim zv minem hvse ich si galaden han ### trinchen vnd spise ich in gvetlichen bot ### vnd gab in mine gabe wi sol ich raten in den tot
###### 2157 | ### Di livte wænent lihte daz ich si verzaget ### deheinen minen dienest han ich in versaget ### den vil edeln fversten vnt den iren man ### ovch riwet mich div vrivntschaft di ich mit in geworben han
###### 2158 | ### Giselher dem degene gab ich di tohter min ### sine chvnde in dirre werlde niht baz verwendet sin ### vf zvht vnde vf ere vf triwe vnde ovch vf gvt ### ine gesach ni kvenech so ivngen so tvgentlich gemvt
###### 2159 | ### <Do> sprach aber Criemhilt vil edel Rvedger ### nv la dich erbarmen vnser beider ser ### min vnde ovch des kveneges gedenche wol dar an ### daz nie wirt deheiner so leide geste gewan [402a]
###### 2160 | ### Do sprach der margrave wider daz edel wip ### ez mvz hivte gelten der Rvedegeres lip ### swaz ir vnd ovch min herre mir liebes habt getan ### dar vmbe mvz ich ersterben daz mag niht langer gestan
###### 2161 | ### Ich weiz wol daz noch hivte mine bverge vnde miniv lant ### iv mvezen ledech werden von ir eteliches hant ### ich bevilhiv vf genade min wip vnde miniv kint ### vnd ovch di vil ellenden di da ce Bechelaren sint
| ### Nv lon dir got Rvedeger sprach der kvenech do ### er vnt div chvneginne si wrden beide vro ### vns svln dine livte vil wol bevolhen wesen ### wol trwe ich minem heile dv maht selbe genesen
###### 2163 | ### Nv liez er an di wage sele vnd lip ### do begonde weinen daz Ecelen wip ### er sprach ich mvz iv leisten als ich gelobt han ### owe der minen frivnde di ich vil vngerne bestan
###### 2164 | ### Man sah in von dem chvenege vil trvrechlichen gen ### do vande er sine recken vil nahen vor im sten ### er sprach ir svlt ivch waffen alle mine man ### di chvenen Bvrgonden di mvz ich leider bestan
| ### Si hiezen balde springen da man ir geweffen vant ### ez der helm wære oder des schildes rant ### von ir ingesinde wart ez dar getragen ### sit horten leidiv mære di stolzen ellenden sagen
###### 2166 | ### Gewaffent wart do Rvedger mit fvnf hvndert man ### dar veber zwelf recken ce helfe er do gewan ### di wolden pris erwerben in des stvrmes not ### sin wessen niht des daz in so nahete der tot
###### 2167 | ### Do sah man Rvedegeren vnder helm gan ### ez trvgen swert div sharpfen di Rvedegeres man ### dar zv vor ir handen di liehten schilde breit ### daz sach der videlære ez was im groezliche leit
| ### Do sah der ivnge Giselher sinen sweher gen ### mit vf gebvndem [402b] helme wi moht er do versten ### waz er da meinte niwan allez gvt ### des wart der kvenech edele so rehte vroelich gemvt
###### 2169 | ### Nv wol mich solher vrivnt sprach Giselher der degen ### di wir han gewnnen vf<n> disen wegen ### wir svln mines wibes vil wol genizzen hie ### mir ist lieb vf mine triwe daz ie div hirat ergie
###### 2170 | ### Ine weiz wes ir ivch troestet sprah <do> der spilman ### wa <gesahetir> ie dvrh svne so manegen helt gan ### mit vf gebvnden helmen di trvegen swert en hant ### an vns wil dienen Rvedeger sine bverge vnd siniv lant
| ### Bedaz der videlære di rede vol gesprach ### Rvedegern den edeln man vor dem hvse sach ### sinen schilt den gvten satzet er fver den fvz ### do mvs er sinen frivnden versagen dienest vnd grvz
###### 2172 | ### Der edel margrave rief in den sal ### ir chvenen Nibelvnge nv wert ivch vber al ### ir soldet min geniezen nv engeltet ir min ### ê do waren wir vrivnde der triwen wil ih ledech sin
###### 2173 | ### Do erscrachten dirre mære di nothafen man ### wande ir deheiner vrevden da von niht gewan ### daz mit in wolde striten dem si wa waren holt ### si heten von ir vienden michel arbeit gedolt
| ### Nvne welle got von himele sprach Gventher der degen ### daz ir ivch genaden svlt an vns bewegen ### vnt der vil grozen triwe der wir doch heten mvt ### ich wil iv des getrwen daz irz nimmer getvt
###### 2175 | ### Iane mach iches niht gelazen sprah do der chvene man ### ich mvz mit iv striten wand ichez gelobt han ### nv wert ivch chvnen helde so lieb iv si der lip ### mich en woldes niht erlazen des kvenech Eclen wip
###### 2176 | ### Ir wider sagt vns <nv> ce spate sprah do der kvnech her ### nv mvez iv got vergeltn– [403a] vil edel Rvedeger ### triwe vnde minne di ir vns habt getan ### ob irz an dem ende woldet gvetlich/er <lan>
| ### Wir soldenz immer dienen daz ir vns habt gegeben ### ir vnde mine mage ob ir vns liezet leben ### der herlichen gabe di ir vns brahtet her ### in Eceln lant mit triwen des denchet edel Rvedger
###### 2178 | ### Wi wol ich iv des gvnde sprach Rvedger der degen ### daz ich iv mine gabe mit vollen solde geben ### also willechlichen als ich des hete wan ### sone wrde mir dar vmbe nimmer schelten getan
###### 2179 | ### Erwindet edel Rvedeger sprach do Gernot ### wand ez wirt deheiner gesten nie erbot ### so rehte minnechlichen so ir vns habt getan ### des svlt ir wol geniezen ob wir bi lebene bestan
| ### Daz wolde <got> sprach Rvedger vil edel Gernot ### daz ir ce Rine wæret vnde ich wære tot ### mit etelichen eren sit ich ivch sol bestan ### ezen wart noch nie an helden wirs von frivnden getan
###### 2181 | ### Nv lon iv got her Rvedger sprach aber Gernot ### der vil richen gabe mich riwet iwer tot ### sol an iv verderben so tvgentlicher mvt ### hi trage ich iwer waffen daz <ir> mir gabet helt gvt
###### 2182 | ### Daz ist mir nie geswichen in aller dirre not ### vnder sinen ecken lit manich ritter tot ### ez ist lvter vnde stæte herlich vnd gvt ### ich wæne so richer gabe ein recke nimmer mer getvt
| ### Vnde welt ir niht erwinden irn welt zv zvns gan ### slaht ir mir iht der vrivnde di ich noh hinne han ### mit iwer selbes swerte nim ich iv den lip ### so riwet ir mich Rvedeger vnde iwer herlich wip
###### 2184 | ### Daz wolde got her Gernot vnde moeht daz er gan ### daz aller iwer wille wære hi getan ### vnt daz genesen wære iwerr frivnde lip ### ia sol iv wol getrvtet beide min tohter vnde min wip [403b]
###### 2185 | ### Do sprach von Bvrgonden der shoenen Vten chint ### wi tvt ir so her Rvedeger di mit mir chomen sint ### di sint iv alle wæge ir grifet vebel zv ### di iwern shonen tohter welt ir verwitwen ce frv
###### 2186 | ### <· wenne> ir vnd iwer rechen mit strite mich bestat ### wi rehte vnvrivntliche ir daz schinen lat ### daz ich iv wol getrwe fver alle ander man ### da von ich zeinem wibe iwer tohter mir gewan
###### 2187 | ### Gedenchet iwer triwe vil edel kvnech her ### gesende ivch got von hinnen so sprach Rvedger ### lat di ivnchvrowen niht engeltn min ### dvrch iwer selbes tvgende so rvchet ir genædech sin
###### 2188 | ### Daz tæt ich pillichen sprach Giseher daz chint ### di hohen mine mage di noch hir inne sint ### svln di vor iv ersterben so mvz gescheiden sin ### div vil stæte vrivntschapft zv dir vnd ovch der tohter din
| ### Nv mvez vns got genaden sprah der chvene man ### do hvoben si di schilde also si wolden dan ### striten zv den gesten in Criemhilde sal ### do rief vil lvte Hagene von der stiegen her ce tal
###### 2190 | ### Belibet eine wile vil edel Rvedger ### also sprach do Hagene wir wolden reden mer ### ich vnd mine herren als vns des twinget not ### waz mach gehelfen Eceln vnser ellenden not
###### 2191 | ### Ich sten in grozen sorgen sprach aber Hagene ### den schilt den mir gap vrov Gotelint ce tragene ### den habent mir di Hivnen cerhowen vor der hant ### ich friwentliche in daz Eceln lant
| ### Daz des got von himele gerv^chen wolde ### daz ich schilt so gvten noch tragen solde ### so den dv hast vor hende vil edel Rvedeger ### so bedorft ich in den stvermen deheiner halsperge mer
###### 2193 | ### Vil gerne ich dir wære gvt mit minem schilde ### torst ich dirn bieten vor Criemhilde ### doch nim dv in hin Hagene vnt tragen an der hant ### hey soldestv in fveren [404a] heim in der Bvrgonden lant
###### 2194 | ### Do er im so willechlichen den schilt ce gebene bot ### do wart genvger ovgen von heizen træhen rot ### ez was div leste gabe di sit immer mer ### gebot deheinem degene von Bechelaren Rvedeger
| ### Swi grimme Hagen wære vnd swi herte gemvt ### ia erbarmte im div gabe di der helt gvt ### bi sinen lesten ziten so nahen het getan ### vil manech ritter edele mit im trvren began
###### 2196 | ### Nv lon iv got von himele vil edel Rvdger ### ez wirt iwer gelichen deheiner nimmer mer ### der ellenden recken so herliche geb ### got sol daz gebieten daz iwer tvgent immer leb
###### 2197 | ### So we mir dirre mære sprach aber Hagene ### wir heten ander swære so vil ce tragene ### svln wir mit frivnden striten daz si got gechleit ### do sprach der margrave daz ist mir innechlichen leit
| ### Nv lon iv got der gabe vil edel Rvedeger ### swi halt gein iv gebaren dise recken her ### daz nimmer ivch gerveret in strite hi min hant ### ob ir si alle slveget di von Bvrgonden lant
###### 2199 | ### Des neig im mit zvehten der gvte Rvedeger ### si weinten allenthalben daz disiv hercen ser ### niemen gescheiden chvnde daz was ein michel not ### vater maneger tvgende lach an Rvedgeren tot
###### 2200 | ### Do sprach von dem hvse Volker der spilman ### sit min geselle Hagene den fride hat getan ### den svlt ovch ir stæte haben von miner hant ### daz habt ir wol verdienet do wir chomen in daz lant
| ### Vil edel margrave ir svlt min bote sin ### dise roten bovge gap mir div margravin ### daz ich si tragen solde hi cer hogezit ### di mveget ir selbe schoven daz ir min gezivch des sit
###### 2202 | ### Daz wolde got von himele sprach do Rvedeger ### daz iv div margravinne noch solde geben mer ### div [404b] mære sag ich gerne der trivtinne min ### gesihe ich si gesvnde des mveget ir ane zwivel sin
###### 2203 | ### Als er im daz gelobte den schilt hvp Rvedeger ### des mvotes er retobete done beit er da niht mer ### do lief er zv den gesten einem degen gelich ### manegen slach vil swinden slvch der margrave rich
| ### Di zwene stvnden hoher Volker vnd Hagene ### wand ez im ê gelobten di chvenen degene ### noch vand er also chvenen bi dem tvrne stan ### daz Rvedeger des strites mit grozen sorgen began
###### 2205 | ### Dvrch mortrachen willen so liezen in dar in ### Gventher vnd Gernot si heten helde sin ### do stvnt vf hoher Giselher zware ez was im leit ### er versach sich noch des lebenes dar vmb er Rvedgern meit
###### 2206 | ### Do sprachen zv den fienden des margraven man ### man sach si nach ir herren vil degenliche gan ### div snidenden waffen si trvgen an der hant ### des brast da vil der helme vnd manech herlicher rant
| ### Do slvgen di vil mveden manegen herten slach ### den von Bechelaren der eben vnd tiefe wach ### dvrch di liehten ringe vaste vnz vf daz verch ### si taten in dem stvrme div vil herlichen werch
###### 2208 | ### Daz edel ingesinde was nv chomen gar dar in ### Volker vnd Hagene di sprvngen balde hin ### sine gaben vride niemen <wan> dem einem man ### von ir beider handen daz plvot dvrh helme nider ran
###### 2209 | ### Wi rehte grimmechlichen vil manech swert dar inne erchlanch ### vil der schilde spangen vz den slegen spranch ### des reis ir schiltgesteine verhowen in daz plvot ### si vahten also grimme daz man ez nimmer mer getvt
| ### Der <vogt> von Bechlaren gie wider vnd dan ### also der mit ellen in [405a] stvrme werben chan ### dem tet des tages Rvedeger harte wol gelich ### daz er ein recke wære vil chvne vnt <ovh> vil lobelich
###### 2211 | ### Hi stvnden dise recken Gvnther vnde Gernot ### si slvgen in dem stvrme vil manegen helt tot ### Giseher vnt Danchwart di zwen ez ringe wach ### des frvmten si vil manegen vnz vf ir ivngesten tach
###### 2212 | ### Vil wol zeigete Rvedeger daz er was starch genvch ### chvene vnde wol gewaffent hey waz er helde slvch ### daz sach ein Bvrgonde zornes gie im not ### da von begvnde nahen des edeln Rvedgeres tot
| ### Gernot der starche den helt rvft er an ### er sprach cem margraven ir welt mir miner man ### niht genesen lazen vil edel Rvedger ### daz mvet mich ane maze ichn chans niht an gesehen mer
###### 2214 | ### Nv mag iv iwer gabe wol ce shaden chomen ### sit ir mir miner vrivnde habt so vil genomen ### nv wendet ivch her vmbe vil edel chvene man ### iwer gabe wirt verdienet so ich aller beste chan
###### 2215 | ### ê daz der margrave zv zim vol chom dar ### des mvsen liehte ringe werden missevar ### do sprvngen zv ein ander di ere gernde man ### ir ietwederr schermen fver starche wnden began
| ### Ir swert so scherpfe waren ez enchvnde niht gewegen ### do slvch Gernoten Rvedeger der degen ### dvrch helme vlinsherten daz nider vloz daz plvt ### daz vergalt im schiere der ritter chvene vnd gvt
###### 2217 | ### Di Rvedegeres gabe an hende er hohe wach ### swi wnt er cem tode wære er slvch im einen slach ### dvrch den schilt vil gvten vnz vf div helm gespan ### da von so mvs ersterben der schoenen gotelinde man
###### 2218 | ### Iane wart ni wirs gelonet so richer gabe mer ### do vielen beide erslagene Gernot vnd Rvedeger ### gelich in dem stvrme [405b] von ir beider hant ### aller erst erzvrnede Hagene do er den grozen schaden vant
| ### Do sprach der helt von Tronege ez ist vns vebel chomen ### wir haben an in beiden so grozen schaden genomen ### den nimmer veberwindent ir livte vnd ovh ir lant ### di Rvedegeres helde sint vnser ellenden pfant
###### 2220 | ### Owe mines brvder der tot ist hi gefrvmt ### waz mir der leiden mære zallen ziten chvmt ### ovh mvoz mich immer riwen der edel Rvedger ### der schade ist beidenthalben vnt div vil groezlichen ser
###### 2221 | ### Do Giselher der herre sach sinen sweher tot ### di do dar inne waren di mvsen liden not ### der tot der svchte sere da sin gesinde was ### der von Bechelaren do langer einer niht genas
| ### Do Gventher vnde Giselher vnd ovch Hagene ### Danchwart vnde Volker di gvten degene ### di giengen da si fvnden ligen di zwene man ### do wart da von den helden mit iamer weinen getan
###### 2223 | ### Der tot vns sere rovbet sprach Giselher daz chint ### nv lazet iwer weinen vnd ge wir an den wint ### daz vns di ringe erchvlen vns stritmveden man ### ia wen vns got von himele niht lenger hi ce lebene gan
###### 2224 | ### Den sizzen disen <leinen> sah man manegen degen ### si waren aber mvezech da waren tot gelegen ### di Rvedegeres helde vergangen was der doz ### so lange wert div stille daz sin Eceln verdroz
| ### Owe dirre dieneste sprach des chveneges wip ### dine sint so stæte daz viende lip ### mvge des engelten von Rvedegeres hant ### er wil si wider bringen in der Bvergonden lant
###### 2226 | ### Waz hilfet chvenech Ecel daz wir geteilet han ### mit im swaz er wolde der helt hat missetan ### der vns da solde rêchen der wil der svne pflegen ### des antwrte Volker der vil zierliche degen [406a]
###### 2227 | ### De rede enist <niht> so leider vil edel chveneges wip ### getorste ich heizen liegen alsus edelen lip ### so het ir tivuellichen an Rvedgeren gelogen ### er vnt di sinen degene sint an der svne gar betrogen
| ### Er tet so vollechliche daz im der kvenech gebot ### daz er vnde sin gesinde ist hi gelegen tot ### nv sehet alvmbe Criemhilt wem ir gebieten welt ### iv hat vnz vf den ende gedienet Rvedger der helt
###### 2229 | ### Welt ir des niht gelovben man <solz> sehen lan ### dvrch ir hercenleide so wart do daz getan ### man trvch den helt verhowen da in der chvenech sach ### den Eceln degene so rehte leide ni geschach
###### 2230 | ### Do si den mragraven sahen toten tragen ### ezen chvnde dehein schribær geprieven noch gesach ### di manege vngebære von wibe vnde ovh von man ### div sich von hercen iamer al da zeigen began
| ### Der Eceln iamer wart also groz ### als eines lewen stimme der riche chvenech erdoz ### mit herceleidem wffe alsam tet ovch sin wip ### si klageten vngefvoge des gvten Rvdegeres lip

<<< Übersicht <<< vorige Seite nächste Seite >>>